@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -19,8 +19,8 @@
 from importlib import import_module
 
 from .all import objects
-from .core.object import Object
+from .core.tl_object import TLObject
 
 for k, v in objects.items():
     path, name = v.rsplit(".", 1)
-    Object.all[k] = getattr(import_module("pyrogram.api." + path), name)
+    TLObject.all[k] = getattr(import_module(path), name)
