@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+import os
 import platform
 import re
 from queue import Queue
@@ -30,7 +31,7 @@ class BaseClient:
     class StopTransmission(StopIteration):
         pass
 
-    APP_VERSION = "Pyrogram \U0001f525 {}".format(__version__)
+    APP_VERSION = "Pyrogram {}".format(__version__)
 
     DEVICE_MODEL = "{} {}".format(
         platform.python_implementation(),
@@ -49,13 +50,13 @@ class BaseClient:
     DIALOGS_AT_ONCE = 100
     UPDATES_WORKERS = 1
     DOWNLOAD_WORKERS = 1
-    OFFLINE_SLEEP = 300
+    OFFLINE_SLEEP = 900
     WORKERS = 4
     WORKDIR = "."
     CONFIG_FILE = "./config.ini"
 
     MEDIA_TYPE_ID = {
-        0: "thumbnail",
+        0: "photo_thumbnail",
         1: "chat_photo",
         2: "photo",
         3: "voice",
@@ -64,9 +65,24 @@ class BaseClient:
         8: "sticker",
         9: "audio",
         10: "animation",
-        13: "video_note"
+        13: "video_note",
+        14: "document_thumbnail"
     }
 
+    mime_types_to_extensions = {}
+    extensions_to_mime_types = {}
+
+    with open("{}/mime.types".format(os.path.dirname(__file__)), "r", encoding="UTF-8") as f:
+        for match in re.finditer(r"^([^#\s]+)\s+(.+)$", f.read(), flags=re.M):
+            mime_type, extensions = match.groups()
+
+            extensions = [".{}".format(ext) for ext in extensions.split(" ")]
+
+            for ext in extensions:
+                extensions_to_mime_types[ext] = mime_type
+
+            mime_types_to_extensions[mime_type] = " ".join(extensions)
+
     def __init__(self):
         self.is_bot = None
         self.dc_id = None
@@ -75,7 +91,6 @@ class BaseClient:
         self.date = None
 
         self.rnd_id = MsgId
-        self.channels_pts = {}
 
         self.peers_by_id = {}
         self.peers_by_username = {}
@@ -132,3 +147,12 @@ class BaseClient:
 
     def answer_inline_query(self, *args, **kwargs):
         pass
+
+    def guess_mime_type(self, *args, **kwargs):
+        pass
+
+    def guess_extension(self, *args, **kwargs):
+        pass
+
+    def get_profile_photos(self, *args, **kwargs):
+        pass
