@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -16,12 +16,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
+import time
 from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
+from pyrogram.errors import FloodWait
 from ...ext import BaseClient
 
+log = logging.getLogger(__name__)
+
 
 class Filters:
     ALL = "all"
@@ -33,18 +38,22 @@ class Filters:
 
 
 class GetChatMembers(BaseClient):
-    def get_chat_members(self,
-                         chat_id: Union[int, str],
-                         offset: int = 0,
-                         limit: int = 200,
-                         query: str = "",
-                         filter: str = Filters.ALL) -> "pyrogram.ChatMembers":
-        """Use this method to get the members list of a chat.
+    def get_chat_members(
+        self,
+        chat_id: Union[int, str],
+        offset: int = 0,
+        limit: int = 200,
+        query: str = "",
+        filter: str = Filters.ALL
+    ) -> "pyrogram.ChatMembers":
+        """Get a chunk of the members list of a chat.
 
+        You can get up to 200 chat members at once.
         A chat can be either a basic group, a supergroup or a channel.
         You must be admin to retrieve the members list of a channel (also known as "subscribers").
+        For a more convenient way of getting chat members see :meth:`~Client.iter_chat_members`.
 
-        Args:
+        Parameters:
             chat_id (``int`` | ``str``):
                 Unique identifier (int) or username (str) of the target chat.
 
@@ -77,11 +86,11 @@ class GetChatMembers(BaseClient):
         .. [2] A query string is applicable only for *"all"*, *"kicked"* and *"restricted"* filters only.
 
         Returns:
-            On success, a :obj:`ChatMembers` object is returned.
+            :obj:`ChatMembers`: On success, an object containing a list of chat members is returned.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
-            ``ValueError`` if you used an invalid filter or a chat_id that belongs to a user.
+            RPCError: In case of a Telegram RPC error.
+            ValueError: In case you used an invalid filter or a chat id that belongs to a user.
         """
         peer = self.resolve_peer(chat_id)
 
@@ -90,7 +99,7 @@ class GetChatMembers(BaseClient):
                 self,
                 self.send(
                     functions.messages.GetFullChat(
-                        peer.chat_id
+                        chat_id=peer.chat_id
                     )
                 )
             )
@@ -112,17 +121,22 @@ class GetChatMembers(BaseClient):
             else:
                 raise ValueError("Invalid filter \"{}\"".format(filter))
 
-            return pyrogram.ChatMembers._parse(
-                self,
-                self.send(
-                    functions.channels.GetParticipants(
-                        channel=peer,
-                        filter=filter,
-                        offset=offset,
-                        limit=limit,
-                        hash=0
+            while True:
+                try:
+                    return pyrogram.ChatMembers._parse(
+                        self,
+                        self.send(
+                            functions.channels.GetParticipants(
+                                channel=peer,
+                                filter=filter,
+                                offset=offset,
+                                limit=limit,
+                                hash=0
+                            )
+                        )
                     )
-                )
-            )
+                except FloodWait as e:
+                    log.warning("Sleeping for {}s".format(e.x))
+                    time.sleep(e.x)
         else:
             raise ValueError("The chat_id \"{}\" belongs to a user".format(chat_id))
