@@ -25,22 +25,17 @@ from ...ext import BaseClient
 
 
 class OnMessage(BaseClient):
-    def on_message(self=None,
-                   filters=None,
-                   group: int = 0) -> callable:
-        """Use this decorator to automatically register a function for handling
-        messages. This does the same thing as :meth:`add_handler` using the
-        :class:`MessageHandler`.
+    def on_message(
+        self=None,
+        filters=None,
+        group: int = 0
+    ) -> callable:
+        """Decorator for handling messages.
 
-        .. note::
-            This decorator will wrap your defined function in a tuple consisting of *(Handler, group)*.
+        This does the same thing as :meth:`~pyrogram.Client.add_handler` using the :obj:`~pyrogram.MessageHandler`.
 
-            To reference your own function after it has been decorated, you need to access
-            *my_function[0].callback*, that is, the *callback* field of Handler object which is the the
-            first element in the tuple.
-
-        Args:
-            filters (:obj:`Filters <pyrogram.Filters>`):
+        Parameters:
+            filters (:obj:`~pyrogram.Filters`, *optional*):
                 Pass one or more filters to allow only a subset of messages to be passed
                 in your function.
 
