@@ -16,15 +16,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import binascii
-import mimetypes
 import os
-import struct
 from typing import Union
 
 import pyrogram
 from pyrogram.api import functions, types
-from pyrogram.api.errors import FileIdInvalid
 from pyrogram.client.ext import BaseClient, utils
 from pyrogram.client.types import (
     InputMediaPhoto, InputMediaVideo, InputMediaAudio,
@@ -34,19 +30,21 @@ from pyrogram.client.types.input_media import InputMedia
 
 
 class EditMessageMedia(BaseClient):
-    def edit_message_media(self,
-                           chat_id: Union[int, str],
-                           message_id: int,
-                           media: InputMedia,
-                           reply_markup: "pyrogram.InlineKeyboardMarkup" = None) -> "pyrogram.Message":
-        """Use this method to edit audio, document, photo, or video messages.
+    def edit_message_media(
+        self,
+        chat_id: Union[int, str],
+        message_id: int,
+        media: InputMedia,
+        reply_markup: "pyrogram.InlineKeyboardMarkup" = None
+    ) -> "pyrogram.Message":
+        """Edit audio, document, photo, or video messages.
 
         If a message is a part of a message album, then it can be edited only to a photo or a video. Otherwise,
         message type can be changed arbitrarily. When inline message is edited, new file can't be uploaded.
         Use previously uploaded file via its file_id or specify a URL. On success, if the edited message was sent
         by the bot, the edited Message is returned, otherwise True is returned.
 
-        Args:
+        Parameters:
             chat_id (``int`` | ``str``):
                 Unique identifier (int) or username (str) of the target chat.
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
@@ -55,17 +53,17 @@ class EditMessageMedia(BaseClient):
             message_id (``int``):
                 Message identifier in the chat specified in chat_id.
 
-            media (:obj:`InputMediaAnimation` | :obj:`InputMediaAudio` | :obj:`InputMediaDocument` | :obj:`InputMediaPhoto` | :obj:`InputMediaVideo`)
+            media (:obj:`InputMedia`)
                 One of the InputMedia objects describing an animation, audio, document, photo or video.
 
             reply_markup (:obj:`InlineKeyboardMarkup`, *optional*):
                 An InlineKeyboardMarkup object.
 
         Returns:
-            On success, the edited :obj:`Message <pyrogram.Message>` is returned.
+            :obj:`Message`: On success, the edited message is returned.
 
         Raises:
-            :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
+            RPCError: In case of a Telegram RPC error.
         """
         style = self.html if media.parse_mode.lower() == "html" else self.markdown
         caption = media.caption
@@ -93,28 +91,7 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                try:
-                    decoded = utils.decode(media.media)
-                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                    unpacked = struct.unpack(fmt, decoded)
-                except (AssertionError, binascii.Error, struct.error):
-                    raise FileIdInvalid from None
-                else:
-                    if unpacked[0] != 2:
-                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                        if media_type:
-                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                        else:
-                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                    media = types.InputMediaPhoto(
-                        id=types.InputPhoto(
-                            id=unpacked[2],
-                            access_hash=unpacked[3],
-                            file_reference=b""
-                        )
-                    )
+                media = utils.get_input_media_from_file_id(media.media, 2)
 
         if isinstance(media, InputMediaVideo):
             if os.path.exists(media.media):
@@ -122,7 +99,8 @@ class EditMessageMedia(BaseClient):
                     functions.messages.UploadMedia(
                         peer=self.resolve_peer(chat_id),
                         media=types.InputMediaUploadedDocument(
-                            mime_type=mimetypes.types_map[".mp4"],
+                            mime_type=self.guess_mime_type(media.media) or "video/mp4",
+                            thumb=None if media.thumb is None else self.save_file(media.thumb),
                             file=self.save_file(media.media),
                             attributes=[
                                 types.DocumentAttributeVideo(
@@ -131,7 +109,9 @@ class EditMessageMedia(BaseClient):
                                     w=media.width,
                                     h=media.height
                                 ),
-                                types.DocumentAttributeFilename(os.path.basename(media.media))
+                                types.DocumentAttributeFilename(
+                                    file_name=os.path.basename(media.media)
+                                )
                             ]
                         )
                     )
@@ -149,28 +129,7 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                try:
-                    decoded = utils.decode(media.media)
-                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                    unpacked = struct.unpack(fmt, decoded)
-                except (AssertionError, binascii.Error, struct.error):
-                    raise FileIdInvalid from None
-                else:
-                    if unpacked[0] != 4:
-                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                        if media_type:
-                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                        else:
-                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                    media = types.InputMediaDocument(
-                        id=types.InputDocument(
-                            id=unpacked[2],
-                            access_hash=unpacked[3],
-                            file_reference=b""
-                        )
-                    )
+                media = utils.get_input_media_from_file_id(media.media, 4)
 
         if isinstance(media, InputMediaAudio):
             if os.path.exists(media.media):
@@ -178,7 +137,8 @@ class EditMessageMedia(BaseClient):
                     functions.messages.UploadMedia(
                         peer=self.resolve_peer(chat_id),
                         media=types.InputMediaUploadedDocument(
-                            mime_type=mimetypes.types_map.get("." + media.media.split(".")[-1], "audio/mpeg"),
+                            mime_type=self.guess_mime_type(media.media) or "audio/mpeg",
+                            thumb=None if media.thumb is None else self.save_file(media.thumb),
                             file=self.save_file(media.media),
                             attributes=[
                                 types.DocumentAttributeAudio(
@@ -186,7 +146,9 @@ class EditMessageMedia(BaseClient):
                                     performer=media.performer,
                                     title=media.title
                                 ),
-                                types.DocumentAttributeFilename(os.path.basename(media.media))
+                                types.DocumentAttributeFilename(
+                                    file_name=os.path.basename(media.media)
+                                )
                             ]
                         )
                     )
@@ -204,28 +166,7 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                try:
-                    decoded = utils.decode(media.media)
-                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                    unpacked = struct.unpack(fmt, decoded)
-                except (AssertionError, binascii.Error, struct.error):
-                    raise FileIdInvalid from None
-                else:
-                    if unpacked[0] != 9:
-                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                        if media_type:
-                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                        else:
-                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                    media = types.InputMediaDocument(
-                        id=types.InputDocument(
-                            id=unpacked[2],
-                            access_hash=unpacked[3],
-                            file_reference=b""
-                        )
-                    )
+                media = utils.get_input_media_from_file_id(media.media, 9)
 
         if isinstance(media, InputMediaAnimation):
             if os.path.exists(media.media):
@@ -233,7 +174,8 @@ class EditMessageMedia(BaseClient):
                     functions.messages.UploadMedia(
                         peer=self.resolve_peer(chat_id),
                         media=types.InputMediaUploadedDocument(
-                            mime_type=mimetypes.types_map[".mp4"],
+                            mime_type=self.guess_mime_type(media.media) or "video/mp4",
+                            thumb=None if media.thumb is None else self.save_file(media.thumb),
                             file=self.save_file(media.media),
                             attributes=[
                                 types.DocumentAttributeVideo(
@@ -242,7 +184,9 @@ class EditMessageMedia(BaseClient):
                                     w=media.width,
                                     h=media.height
                                 ),
-                                types.DocumentAttributeFilename(os.path.basename(media.media)),
+                                types.DocumentAttributeFilename(
+                                    file_name=os.path.basename(media.media)
+                                ),
                                 types.DocumentAttributeAnimated()
                             ]
                         )
@@ -261,28 +205,7 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                try:
-                    decoded = utils.decode(media.media)
-                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                    unpacked = struct.unpack(fmt, decoded)
-                except (AssertionError, binascii.Error, struct.error):
-                    raise FileIdInvalid from None
-                else:
-                    if unpacked[0] != 10:
-                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                        if media_type:
-                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                        else:
-                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                    media = types.InputMediaDocument(
-                        id=types.InputDocument(
-                            id=unpacked[2],
-                            access_hash=unpacked[3],
-                            file_reference=b""
-                        )
-                    )
+                media = utils.get_input_media_from_file_id(media.media, 10)
 
         if isinstance(media, InputMediaDocument):
             if os.path.exists(media.media):
@@ -290,10 +213,13 @@ class EditMessageMedia(BaseClient):
                     functions.messages.UploadMedia(
                         peer=self.resolve_peer(chat_id),
                         media=types.InputMediaUploadedDocument(
-                            mime_type=mimetypes.types_map.get("." + media.media.split(".")[-1], "text/plain"),
+                            mime_type=self.guess_mime_type(media.media) or "application/zip",
+                            thumb=None if media.thumb is None else self.save_file(media.thumb),
                             file=self.save_file(media.media),
                             attributes=[
-                                types.DocumentAttributeFilename(os.path.basename(media.media))
+                                types.DocumentAttributeFilename(
+                                    file_name=os.path.basename(media.media)
+                                )
                             ]
                         )
                     )
@@ -311,28 +237,7 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                try:
-                    decoded = utils.decode(media.media)
-                    fmt = "<iiqqqqi" if len(decoded) > 24 else "<iiqq"
-                    unpacked = struct.unpack(fmt, decoded)
-                except (AssertionError, binascii.Error, struct.error):
-                    raise FileIdInvalid from None
-                else:
-                    if unpacked[0] not in (5, 10):
-                        media_type = BaseClient.MEDIA_TYPE_ID.get(unpacked[0], None)
-
-                        if media_type:
-                            raise FileIdInvalid("The file_id belongs to a {}".format(media_type))
-                        else:
-                            raise FileIdInvalid("Unknown media type: {}".format(unpacked[0]))
-
-                    media = types.InputMediaDocument(
-                        id=types.InputDocument(
-                            id=unpacked[2],
-                            access_hash=unpacked[3],
-                            file_reference=b""
-                        )
-                    )
+                media = utils.get_input_media_from_file_id(media.media, 5)
 
         r = self.send(
             functions.messages.EditMessage(
