@@ -22,12 +22,12 @@ import pyrogram
 from pyrogram.api import types
 from .inline_query_result import InlineQueryResult
 from ..messages_and_media import Location
-from ..pyrogram_type import PyrogramType
+from ..object import Object
 from ..update import Update
 from ..user_and_chats import User
 
 
-class InlineQuery(PyrogramType, Update):
+class InlineQuery(Object, Update):
     """An incoming inline query.
 
     When the user sends an empty query, your bot could return some default or trending results.
@@ -92,7 +92,7 @@ class InlineQuery(PyrogramType, Update):
         switch_pm_text: str = "",
         switch_pm_parameter: str = ""
     ):
-        """Bound method *answer* of :obj:`InlineQuery <pyrogram.InlineQuery>`.
+        """Bound method *answer* of :obj:`InlineQuery`.
 
         Use this method as a shortcut for:
 
@@ -109,7 +109,7 @@ class InlineQuery(PyrogramType, Update):
                 inline_query.answer([...])
 
         Parameters:
-            results (List of :obj:`InlineQueryResult <pyrogram.InlineQueryResult>`):
+            results (List of :obj:`InlineQueryResult`):
                 A list of results for the inline query.
 
             cache_time (``int``, *optional*):
