@@ -20,10 +20,11 @@ from . import InputMedia
 
 
 class InputMediaAudio(InputMedia):
-    """This object represents an audio to be sent inside an album.
+    """An audio to be sent inside an album.
+
     It is intended to be used with :obj:`send_media_group() <pyrogram.Client.send_media_group>`.
 
-    Args:
+    Parameters:
         media (``str``):
             Audio to send.
             Pass a file_id as string to send an audio that exists on the Telegram servers or
@@ -32,16 +33,15 @@ class InputMediaAudio(InputMedia):
         thumb (``str``, *optional*):
             Thumbnail of the music file album cover.
             The thumbnail should be in JPEG format and less than 200 KB in size.
-            A thumbnail's width and height should not exceed 90 pixels.
+            A thumbnail's width and height should not exceed 320 pixels.
             Thumbnails can't be reused and can be only uploaded as a new file.
 
         caption (``str``, *optional*):
             Caption of the audio to be sent, 0-1024 characters
 
         parse_mode (``str``, *optional*):
-            Use :obj:`MARKDOWN <pyrogram.ParseMode.MARKDOWN>` or :obj:`HTML <pyrogram.ParseMode.HTML>`
-            if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in your caption.
-            Defaults to Markdown.
+            Pass "markdown" or "html" if you want Telegram apps to show bold, italic, fixed-width text or inline URLs
+            in your caption. Defaults to "markdown".
 
         duration (``int``, *optional*):
             Duration of the audio in seconds
