@@ -17,13 +17,14 @@
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 from pyrogram.api.types import InputPhoneContact as RawInputPhoneContact
+
 from pyrogram.session.internals import MsgId
-from ..pyrogram_type import PyrogramType
+from ..object import Object
 
 
-class InputPhoneContact(PyrogramType):
+class InputPhoneContact(Object):
     """A Phone Contact to be added in your Telegram address book.
-    It is intended to be used with :meth:`add_contacts() <pyrogram.Client.add_contacts>`
+    It is intended to be used with :meth:`~Client.add_contacts() <pyrogram.Client.add_contacts>`
 
     Parameters:
         phone (``str``):
