@@ -18,16 +18,17 @@
 
 from functools import lru_cache
 from struct import pack
+from typing import List
 
 import pyrogram
 from pyrogram.api import types, functions
 from pyrogram.errors import StickersetInvalid
-from .photo_size import PhotoSize
-from ..pyrogram_type import PyrogramType
+from .thumbnail import Thumbnail
+from ..object import Object
 from ...ext.utils import encode
 
 
-class Sticker(PyrogramType):
+class Sticker(Object):
     """A sticker.
 
     Parameters:
@@ -40,9 +41,6 @@ class Sticker(PyrogramType):
         height (``int``):
             Sticker height.
 
-        thumb (:obj:`PhotoSize`, *optional*):
-            Sticker thumbnail in the .webp or .jpg format.
-
         file_name (``str``, *optional*):
             Sticker file name.
 
@@ -60,12 +58,15 @@ class Sticker(PyrogramType):
 
         set_name (``str``, *optional*):
             Name of the sticker set to which the sticker belongs.
+
+        thumbs (List of :obj:`Thumbnail`, *optional*):
+            Sticker thumbnails in the .webp or .jpg format.
     """
 
     # TODO: Add mask position
 
     __slots__ = [
-        "file_id", "thumb", "file_name", "mime_type", "file_size", "date", "width", "height", "emoji", "set_name"
+        "file_id", "file_name", "mime_type", "file_size", "date", "width", "height", "emoji", "set_name", "thumbs"
     ]
 
     def __init__(
@@ -75,18 +76,17 @@ class Sticker(PyrogramType):
         file_id: str,
         width: int,
         height: int,
-        thumb: PhotoSize = None,
         file_name: str = None,
         mime_type: str = None,
         file_size: int = None,
         date: int = None,
         emoji: str = None,
-        set_name: str = None
+        set_name: str = None,
+        thumbs: List[Thumbnail] = None
     ):
         super().__init__(client)
 
         self.file_id = file_id
-        self.thumb = thumb
         self.file_name = file_name
         self.mime_type = mime_type
         self.file_size = file_size
@@ -94,7 +94,8 @@ class Sticker(PyrogramType):
         self.width = width
         self.height = height
         self.emoji = emoji
-        self.set_name = set_name
+        self.set_name = set_name,
+        self.thumbs = thumbs
         # self.mask_position = mask_position
 
     @staticmethod
@@ -135,7 +136,6 @@ class Sticker(PyrogramType):
             ),
             width=image_size_attributes.w if image_size_attributes else 0,
             height=image_size_attributes.h if image_size_attributes else 0,
-            thumb=PhotoSize._parse(client, sticker.thumbs),
             # TODO: mask_position
             set_name=set_name,
             emoji=sticker_attributes.alt or None,
@@ -143,5 +143,6 @@ class Sticker(PyrogramType):
             mime_type=sticker.mime_type,
             file_name=file_name,
             date=sticker.date,
+            thumbs=Thumbnail._parse(client, sticker),
             client=client
         )
