@@ -19,14 +19,14 @@
 import pyrogram
 from pyrogram.api import types
 from .location import Location
-from ..pyrogram_type import PyrogramType
+from ..object import Object
 
 
-class Venue(PyrogramType):
-    """This object represents a venue.
+class Venue(Object):
+    """A venue.
 
-    Args:
-        location (:obj:`Location <pyrogram.Location>`):
+    Parameters:
+        location (:obj:`Location`):
             Venue location.
 
         title (``str``):
@@ -44,14 +44,18 @@ class Venue(PyrogramType):
 
     """
 
-    def __init__(self,
-                 *,
-                 client: "pyrogram.client.ext.BaseClient",
-                 location: Location,
-                 title: str,
-                 address: str,
-                 foursquare_id: str = None,
-                 foursquare_type: str = None):
+    __slots__ = ["location", "title", "address", "foursquare_id", "foursquare_type"]
+
+    def __init__(
+        self,
+        *,
+        client: "pyrogram.BaseClient" = None,
+        location: Location,
+        title: str,
+        address: str,
+        foursquare_id: str = None,
+        foursquare_type: str = None
+    ):
         super().__init__(client)
 
         self.location = location
