@@ -712,3 +712,24 @@ class AccessTokenInvalid(BadRequest):
     MESSAGE = __doc__
 
 
+class InviteHashExpired(BadRequest):
+    """The chat invite link is no longer valid"""
+    ID = "INVITE_HASH_EXPIRED"
+    """``str``: RPC Error ID"""
+    MESSAGE = __doc__
+
+
+class UserBannedInChannel(BadRequest):
+    """You are limited, check @SpamBot for details"""
+    ID = "USER_BANNED_IN_CHANNEL"
+    """``str``: RPC Error ID"""
+    MESSAGE = __doc__
+
+
+class MessageEditTimeExpired(BadRequest):
+    """You can no longer edit this message"""
+    ID = "MESSAGE_EDIT_TIME_EXPIRED"
+    """``str``: RPC Error ID"""
+    MESSAGE = __doc__
+
+
