@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -23,10 +23,10 @@ from io import BytesIO
 from os import urandom
 
 from pyrogram.api import functions, types
-from pyrogram.api.core import Object, Long, Int
+from pyrogram.api.core import TLObject, Long, Int
 from pyrogram.connection import Connection
 from pyrogram.crypto import AES, RSA, Prime
-from .internals import MsgId, DataCenter
+from .internals import MsgId
 
 log = logging.getLogger(__name__)
 
@@ -34,26 +34,16 @@ log = logging.getLogger(__name__)
 class Auth:
     MAX_RETRIES = 5
 
-    CURRENT_DH_PRIME = int(
-        "C71CAEB9C6B1C9048E6C522F70F13F73980D40238E3E21C14934D037563D930F"
-        "48198A0AA7C14058229493D22530F4DBFA336F6E0AC925139543AED44CCE7C37"
-        "20FD51F69458705AC68CD4FE6B6B13ABDC9746512969328454F18FAF8C595F64"
-        "2477FE96BB2A941D5BCD1D4AC8CC49880708FA9B378E3C4F3A9060BEE67CF9A4"
-        "A4A695811051907E162753B56B0F6B410DBA74D8A84B2A14B3144E0EF1284754"
-        "FD17ED950D5965B4B9DD46582DB1178D169C6BC465B0D6FF9CA3928FEF5B9AE4"
-        "E418FC15E83EBEA0F87FA9FF5EED70050DED2849F47BF959D956850CE929851F"
-        "0D8115F635B105EE2E4E15D04B2454BF6F4FADF034B10403119CD8E3B92FCC5B",
-        16
-    )
-
-    def __init__(self, dc_id: int, test_mode: bool, proxy: type):
+    def __init__(self, dc_id: int, test_mode: bool, ipv6: bool, proxy: dict):
         self.dc_id = dc_id
         self.test_mode = test_mode
+        self.ipv6 = ipv6
+        self.proxy = proxy
 
-        self.connection = Connection(DataCenter(dc_id, test_mode), proxy)
+        self.connection = None
 
     @staticmethod
-    def pack(data: Object) -> bytes:
+    def pack(data: TLObject) -> bytes:
         return (
             bytes(8)
             + Long(MsgId())
@@ -64,9 +54,9 @@ class Auth:
     @staticmethod
     def unpack(b: BytesIO):
         b.seek(20)  # Skip auth_key_id (8), message_id (8) and message_length (4)
-        return Object.read(b)
+        return TLObject.read(b)
 
-    def send(self, data: Object):
+    def send(self, data: TLObject):
         data = self.pack(data)
         self.connection.send(data)
         response = BytesIO(self.connection.recv())
@@ -83,6 +73,8 @@ class Auth:
         # The server may close the connection at any time, causing the auth key creation to fail.
         # If that happens, just try again up to MAX_RETRIES times.
         while True:
+            self.connection = Connection(self.dc_id, self.test_mode, self.ipv6, self.proxy)
+
             try:
                 log.info("Start creating a new auth key on DC{}".format(self.dc_id))
 
@@ -91,8 +83,19 @@ class Auth:
                 # Step 1; Step 2
                 nonce = int.from_bytes(urandom(16), "little", signed=True)
                 log.debug("Send req_pq: {}".format(nonce))
-                res_pq = self.send(functions.ReqPq(nonce))
+                res_pq = self.send(functions.ReqPqMulti(nonce=nonce))
                 log.debug("Got ResPq: {}".format(res_pq.server_nonce))
+                log.debug("Server public key fingerprints: {}".format(res_pq.server_public_key_fingerprints))
+
+                for i in res_pq.server_public_key_fingerprints:
+                    if i in RSA.server_public_keys:
+                        log.debug("Using fingerprint: {}".format(i))
+                        public_key_fingerprint = i
+                        break
+                    else:
+                        log.debug("Fingerprint unknown: {}".format(i))
+                else:
+                    raise Exception("Public key not found")
 
                 # Step 3
                 pq = int.from_bytes(res_pq.pq, "big")
@@ -107,18 +110,18 @@ class Auth:
                 new_nonce = int.from_bytes(urandom(32), "little", signed=True)
 
                 data = types.PQInnerData(
-                    res_pq.pq,
-                    int.to_bytes(p, 4, "big"),
-                    int.to_bytes(q, 4, "big"),
-                    nonce,
-                    server_nonce,
-                    new_nonce,
+                    pq=res_pq.pq,
+                    p=p.to_bytes(4, "big"),
+                    q=q.to_bytes(4, "big"),
+                    nonce=nonce,
+                    server_nonce=server_nonce,
+                    new_nonce=new_nonce,
                 ).write()
 
                 sha = sha1(data).digest()
                 padding = urandom(- (len(data) + len(sha)) % 255)
                 data_with_hash = sha + data + padding
-                encrypted_data = RSA.encrypt(data_with_hash, res_pq.server_public_key_fingerprints[0])
+                encrypted_data = RSA.encrypt(data_with_hash, public_key_fingerprint)
 
                 log.debug("Done encrypt data with RSA")
 
@@ -126,19 +129,19 @@ class Auth:
                 log.debug("Send req_DH_params")
                 server_dh_params = self.send(
                     functions.ReqDHParams(
-                        nonce,
-                        server_nonce,
-                        int.to_bytes(p, 4, "big"),
-                        int.to_bytes(q, 4, "big"),
-                        res_pq.server_public_key_fingerprints[0],
-                        encrypted_data
+                        nonce=nonce,
+                        server_nonce=server_nonce,
+                        p=p.to_bytes(4, "big"),
+                        q=q.to_bytes(4, "big"),
+                        public_key_fingerprint=public_key_fingerprint,
+                        encrypted_data=encrypted_data
                     )
                 )
 
                 encrypted_answer = server_dh_params.encrypted_answer
 
-                server_nonce = int.to_bytes(server_nonce, 16, "little", signed=True)
-                new_nonce = int.to_bytes(new_nonce, 32, "little", signed=True)
+                server_nonce = server_nonce.to_bytes(16, "little", signed=True)
+                new_nonce = new_nonce.to_bytes(32, "little", signed=True)
 
                 tmp_aes_key = (
                     sha1(new_nonce + server_nonce).digest()
@@ -152,10 +155,10 @@ class Auth:
 
                 server_nonce = int.from_bytes(server_nonce, "little", signed=True)
 
-                answer_with_hash = AES.ige_decrypt(encrypted_answer, tmp_aes_key, tmp_aes_iv)
+                answer_with_hash = AES.ige256_decrypt(encrypted_answer, tmp_aes_key, tmp_aes_iv)
                 answer = answer_with_hash[20:]
 
-                server_dh_inner_data = Object.read(BytesIO(answer))
+                server_dh_inner_data = TLObject.read(BytesIO(answer))
 
                 log.debug("Done decrypting answer")
 
@@ -167,28 +170,28 @@ class Auth:
                 # Step 6
                 g = server_dh_inner_data.g
                 b = int.from_bytes(urandom(256), "big")
-                g_b = int.to_bytes(pow(g, b, dh_prime), 256, "big")
+                g_b = pow(g, b, dh_prime).to_bytes(256, "big")
 
                 retry_id = 0
 
                 data = types.ClientDHInnerData(
-                    nonce,
-                    server_nonce,
-                    retry_id,
-                    g_b
+                    nonce=nonce,
+                    server_nonce=server_nonce,
+                    retry_id=retry_id,
+                    g_b=g_b
                 ).write()
 
                 sha = sha1(data).digest()
                 padding = urandom(- (len(data) + len(sha)) % 16)
                 data_with_hash = sha + data + padding
-                encrypted_data = AES.ige_encrypt(data_with_hash, tmp_aes_key, tmp_aes_iv)
+                encrypted_data = AES.ige256_encrypt(data_with_hash, tmp_aes_key, tmp_aes_iv)
 
                 log.debug("Send set_client_DH_params")
                 set_client_dh_params_answer = self.send(
                     functions.SetClientDHParams(
-                        nonce,
-                        server_nonce,
-                        encrypted_data
+                        nonce=nonce,
+                        server_nonce=server_nonce,
+                        encrypted_data=encrypted_data
                     )
                 )
 
@@ -196,8 +199,8 @@ class Auth:
 
                 # Step 7; Step 8
                 g_a = int.from_bytes(server_dh_inner_data.g_a, "big")
-                auth_key = int.to_bytes(pow(g_a, b, dh_prime), 256, "big")
-                server_nonce = int.to_bytes(server_nonce, 16, "little", signed=True)
+                auth_key = pow(g_a, b, dh_prime).to_bytes(256, "big")
+                server_nonce = server_nonce.to_bytes(16, "little", signed=True)
 
                 # TODO: Handle errors
 
@@ -205,7 +208,7 @@ class Auth:
                 # Security checks
                 #######################
 
-                assert dh_prime == self.CURRENT_DH_PRIME
+                assert dh_prime == Prime.CURRENT_DH_PRIME
                 log.debug("DH parameters check: OK")
 
                 # https://core.telegram.org/mtproto/security_guidelines#g-a-and-g-b-validation
@@ -232,7 +235,7 @@ class Auth:
                 # 3rd message
                 assert nonce == set_client_dh_params_answer.nonce
                 assert server_nonce == set_client_dh_params_answer.server_nonce
-                server_nonce = int.to_bytes(server_nonce, 16, "little", signed=True)
+                server_nonce = server_nonce.to_bytes(16, "little", signed=True)
                 log.debug("Nonce fields check: OK")
 
                 # Step 9
@@ -251,7 +254,6 @@ class Auth:
                 else:
                     raise e
 
-                log.warning("Auth key creation failed. Let's try again: {}".format(repr(e)))
                 time.sleep(1)
                 continue
             else:
