@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -16,9 +16,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from pyrogram.api.core import Message, MsgContainer, Object
-from pyrogram.api.functions import Ping, HttpWait
-from pyrogram.api.types import MsgsAck
+from pyrogram.api.core import Message, MsgContainer, TLObject
+from pyrogram.api.functions import Ping
+from pyrogram.api.types import MsgsAck, HttpWait
 from .msg_id import MsgId
 from .seq_no import SeqNo
 
@@ -26,14 +26,13 @@ not_content_related = [Ping, HttpWait, MsgsAck, MsgContainer]
 
 
 class MsgFactory:
-    def __init__(self, msg_id: MsgId):
-        self.msg_id = msg_id
+    def __init__(self):
         self.seq_no = SeqNo()
 
-    def __call__(self, body: Object) -> Message:
+    def __call__(self, body: TLObject) -> Message:
         return Message(
             body,
-            self.msg_id(),
+            MsgId(),
             self.seq_no(type(body) not in not_content_related),
             len(body)
         )
